# Changelog

## [1.5.0a2](https://github.com/OpenVoiceOS/ovos-core/tree/1.5.0a2) (2025-06-09)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/1.5.0a1...1.5.0a2)

**Merged pull requests:**

- publish coverage report under gh-pages [\#692](https://github.com/OpenVoiceOS/ovos-core/pull/692) ([JarbasAl](https://github.com/JarbasAl))

## [1.5.0a1](https://github.com/OpenVoiceOS/ovos-core/tree/1.5.0a1) (2025-05-27)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/1.4.0a1...1.5.0a1)

**Merged pull requests:**

- feat: intent transformers [\#686](https://github.com/OpenVoiceOS/ovos-core/pull/686) ([JarbasAl](https://github.com/JarbasAl))

## [1.4.0a1](https://github.com/OpenVoiceOS/ovos-core/tree/1.4.0a1) (2025-05-22)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/1.3.1...1.4.0a1)

**Merged pull requests:**

- feat: m2v pipeline [\#681](https://github.com/OpenVoiceOS/ovos-core/pull/681) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
